@@ -12,7 +12,7 @@ use JSON::MaybeXS;
 use Path::Class;
 
 # Have you updated the version number in the POD below?
-our $VERSION = '0.001_02';
+our $VERSION = '0.001_03';
 $VERSION = eval $VERSION;
 
 =head1 NAME
@@ -21,7 +21,7 @@ Test::Mock::LWP::Distilled - make and use LWP mocks, distilled to their essence
 
 =head1 VERSION
 
-This is version 0.001_02 - a developer release.
+This is version 0.001_03 - a developer release.
 
 =head1 SYNOPSIS
 
@@ -551,7 +551,7 @@ sub BUILD {
         $frame++;
     }
     $self->_set__calling_package($package);
-    $self->_set__calling_filename($filename);
+    $self->_set__calling_filename(Path::Class::File->new($filename)->absolute->stringify);
 }
 
 has 'mock_filename' => (
